-- Script to provide ArcSDE 8.3 compatibility with DB2 Spatial Extender V8.1
-- To be used with an ArcSDE 8.3 database which was created with DB2 V7.2
-- and migrated to DB2 V8.1.
-- See the related readme file for more information on using this script.
-- Last updated 06/12/03 - DWA

-- Modify the following connect statement to reference the appropriate database.
-- This should be run either under a dbadmin id or modify the connect
-- statement to provide a dbadmin userid and password.
CONNECT TO sde;

-- Change the coordinate system id (number) for the V8 'UNSPECIFIED' coordinate
-- system to the next available number.  This is so that we can re-use zero
-- for the V7 'UNKNOWN' coordinate system.
update db2gse.gse_coordinate_systems_id
  set coordsys_id =
         (select max(coordsys_id)+1 from db2gse.gse_coordinate_systems_id)
  where coordsys_name = 'UNSPECIFIED';
  ;

-- Add the 'UNKNOWN' coordinate system to gse_coordinate_systems_id with the
-- coordsys_id of zero.  The 'UNKNOWN' coordinate system is already in
-- gse_coordinate_systems as a result of the migration.
insert into db2gse.gse_coordinate_systems_id
  values('UNKNOWN', 0)
  ;

-- Change the spatial reference systems table to use the V7 coordinate
-- system name.
update db2gse.gse_spatial_reference_systems
  set coordsys_name = 'UNKNOWN' where coordsys_name = 'UNSPECIFIED'
;

-- Copy the 'UNSPECIFIED' values from the deprecated V7 catalog view defined in V8
-- to the mirrored V7 version of the coordinate system table
 INSERT INTO db2gse.gse_coord_ref SELECT * FROM db2gse.coord_ref_sys
   WHERE cs_name = 'UNSPECIFIED'
 ;

-- Copy the new V8 spatial reference systems into the V7 table
 INSERT INTO db2gse.gse_spatial_ref
   (srid, sr_name, scid, falsex, falsey, xyunits,
    falsez, zunits, falsem, munits)
   SELECT
     srid, sr_name, csid, falsex, falsey, xyunits,
     falsez, zunits, falsem, munits
   FROM db2gse.spatial_ref_sys
   WHERE srid NOT IN (SELECT srid FROM db2gse.gse_spatial_ref)
 ;


-- Create the triggers to copy values from the V7 db2gse.gse_coord_ref
-- table (inserted by ArcSDE) into the V8 tables.
-- Normally this should be done by using the stored procedure
CREATE TRIGGER db2gse.sde_cs_ins1
AFTER INSERT ON db2gse.gse_coord_ref
REFERENCING NEW AS n FOR EACH ROW
MODE DB2SQL
   insert into db2gse.gse_coordinate_systems
     select sc_name, srtext, auth_name, auth_srid, desc
       from db2gse.gse_coord_ref
         where sc_name = n.sc_name
;

CREATE TRIGGER db2gse.sde_cs_ins2
AFTER INSERT ON db2gse.gse_coord_ref
REFERENCING NEW AS n FOR EACH ROW
MODE DB2SQL
   insert into db2gse.gse_coordinate_systems_id
     select sc_name, scid
       from db2gse.gse_coord_ref
         where sc_name = n.sc_name
;

-- Create the triggers to copy values from the V7 db2gse.gse_coord_ref
-- table (updated by ArcSDE) into the V8 tables.
-- Normally this should be done by using the stored procedure
CREATE TRIGGER db2gse.sde_cs_upd1
AFTER UPDATE ON db2gse.gse_coord_ref
REFERENCING NEW AS n FOR EACH ROW
MODE DB2SQL
   update db2gse.gse_coordinate_systems
     set
       coordsys_name = n.sc_name,
       definition = n.srtext,
       organization = n.auth_name,
       organization_coordsys_id = n.auth_srid,
       description = n.desc
         where coordsys_name = n.sc_name
;

-- Create the triggers to delete values from the V7 db2gse.gse_coord_ref
-- table (deleted by ArcSDE) into the V8 tables.
-- Normally this should be done by using the stored procedure
CREATE TRIGGER db2gse.sde_cs_del1
AFTER DELETE ON db2gse.gse_coord_ref
REFERENCING OLD AS o FOR EACH ROW
MODE DB2SQL
   delete from db2gse.gse_coordinate_systems
         where coordsys_name = o.sc_name
;



--
-- Create the trigger to populate the mirrored V7 catalog table when
-- the V8 catalog table is inserted into.
CREATE TRIGGER db2gse.sde_spat_ref_ins
AFTER INSERT ON db2gse.gse_spatial_reference_systems
REFERENCING NEW AS n FOR EACH ROW
MODE DB2SQL
   insert into db2gse.gse_spatial_ref
     select srid, sr_name, csid, falsex, falsey, xyunits, falsez, zunits, falsem, munits
       from db2gse.spatial_ref_sys
         where srid = n.srs_id
;
--
-- Create the trigger to update the mirrored V7 catalog table when
-- the V8 catalog table is updated.
-- It isn't obvious that this is ever a good idea other than to change the
-- description which doesn't exist in the V7 table.
CREATE TRIGGER db2gse.sde_spat_ref_upd
AFTER UPDATE ON db2gse.gse_spatial_reference_systems
REFERENCING NEW AS n FOR EACH ROW
MODE DB2SQL
   update db2gse.gse_spatial_ref
     set
       falsex = n.x_offset,
       falsey = n.y_offset,
       xyunits = n.x_scale,
       falsez = n.z_offset,
       zunits = n.z_scale,
       falsem = n.m_offset,
       munits = m_scale
         where sr_name = n.srs_name;
;

--
-- Create the trigger to delete from the mirrored V7 catalog table when
-- the V8 catalog table is deleted from.
CREATE TRIGGER db2gse.sde_spat_ref_del
AFTER DELETE ON db2gse.gse_spatial_reference_systems
REFERENCING OLD AS o FOR EACH ROW
MODE DB2SQL
   delete from db2gse.gse_spatial_ref
         where srid = o.srs_id
;



------------------------------------------------
-- DDL Statements for view  "DB2GSE  "."GSE_LAYER_GEOM"
------------------------------------------------
 DROP TABLE  DB2GSE.GSE_LAYER_GEOM;
 CREATE VIEW  "DB2GSE  "."GSE_LAYER_GEOM"  (
                  "GEO_SCHEMA"                      ,
                  "GEO_TABLE"                       ,
                  "GEO_COLUMN"                       ,
                  "GEOMETRY_TYPE"                  ,
                  "SRID"                  ,
                  "STORAGE_TYPE"         ,
                  "CONSTRAINT_NAME"                      ,
                  "NUM_ATTR"                  ,
                  "SRC_ATTR1"              ,
                  "SRC_ATTR2"              ,
                  "SRC_ATTR3"              ,
                  "SRC_ATTR4"              ,
                  "SRC_ATTR5"              ,
                  "SRC_ATTR6"              ,
                  "SRC_ATTR7"              ,
                  "SRC_ATTR8"              ,
                  "SRC_ATTR9"              ,
                  "SRC_ATTR10"              ,
                  "GCID"         ,
                  "PRECISION_LEVEL"         ,
                  "VENDOR_SPECIFIC"              ,
                  "AUTOGC_MODE"         ,
                  "INS_TRIGGER_NAME"             ,
                  "UPD_TRIGGER_NAME"             )
                 AS SELECT  layer_schema, layer_table, layer_column,
                            geometry_type, srid, storage_type,
                            'DUMMY_CONSTRAINT',
                            0,
                            CAST(NULL AS VARCHAR(128)),
                            CAST(NULL AS VARCHAR(128)),
                            CAST(NULL AS VARCHAR(128)),
                            CAST(NULL AS VARCHAR(128)),
                            CAST(NULL AS VARCHAR(128)),
                            CAST(NULL AS VARCHAR(128)),
                            CAST(NULL AS VARCHAR(128)),
                            CAST(NULL AS VARCHAR(128)),
                            CAST(NULL AS VARCHAR(128)),
                            CAST(NULL AS VARCHAR(128)),
                            CAST(NULL AS INTEGER),
                            CAST(NULL AS INTEGER),
                            CAST(NULL AS VARCHAR(256)),
                            CAST(NULL AS INTEGER),
                            CAST(NULL AS VARCHAR(18)),
                            CAST(NULL AS VARCHAR(18))
                FROM db2gse.geometry_columns;

DROP TABLE db2gse.gse_layer;


 CREATE VIEW  "DB2GSE  "."GSE_LAYER"  (
                  "LAYER_TYPE"                  ,
                  "LAYER_CATALOG"             ,
                  "LAYER_SCHEMA"                      ,
                  "LAYER_TABLE"                       ,
                  "LAYER_COLUMN"                       ,
                  "GEO_SCHEMA"                      ,
                  "GEO_TABLE"                       ,
                  "GEO_COLUMN"                       )
                 AS SELECT 1, CAST(NULL AS VARCHAR(30)),
                           layer_schema, layer_table, layer_column,
                           layer_schema, layer_table, layer_column
                 FROM db2gse.geometry_columns;


-- The following are required for a non-DBADM ArcSDE user
grant delete on db2gse.gse_layer to public;
grant delete on db2gse.gse_layer_geom to public;
grant update,insert on db2gse.gse_coord_ref to public;
grant update,insert on db2gse.gse_coordinate_systems to public;
grant update,insert on db2gse.gse_coordinate_systems_id to public;
--grant update,insert on db2gse.gse_spatial_ref to public;

GRANT EXECUTE ON FUNCTION db2gse.GseRaiseError(INTEGER) TO PUBLIC;

GRANT EXECUTE ON FUNCTION db2gse.GseRaiseError
  (INTEGER, varchar(128))
  TO PUBLIC;

GRANT EXECUTE ON FUNCTION db2gse.GseRaiseError
  (INTEGER, varchar(128), varchar(128))
  TO PUBLIC;

GRANT EXECUTE ON FUNCTION db2gse.GseRaiseError
  (INTEGER, varchar(128), varchar(128), varchar(128))
  TO PUBLIC;

-- The following are required for a non-DBADM ArcSDE user to import
-- data which will construct a geometry using the mutators
GRANT EXECUTE ON FUNCTION db2gse.ST_LINESTRING() TO PUBLIC;
GRANT EXECUTE ON FUNCTION db2gse.ST_MULTILINESTRING() TO PUBLIC;
GRANT EXECUTE ON FUNCTION db2gse.ST_MULTIPOINT() TO PUBLIC;
GRANT EXECUTE ON FUNCTION db2gse.ST_MULTIPOLYGON() TO PUBLIC;
GRANT EXECUTE ON FUNCTION db2gse.ST_POINT() TO PUBLIC;
GRANT EXECUTE ON FUNCTION db2gse.ST_POLYGON() TO PUBLIC;
GRANT EXECUTE ON METHOD ANNO_TEXT() FOR db2gse.ST_GEOMETRY TO PUBLIC;
GRANT EXECUTE ON METHOD ANNO_TEXT(VARCHAR(256)) FOR db2gse.ST_GEOMETRY TO PUBLIC;
GRANT EXECUTE ON METHOD AREA() FOR db2gse.ST_GEOMETRY TO PUBLIC;
GRANT EXECUTE ON METHOD AREA(DOUBLE) FOR db2gse.ST_GEOMETRY TO PUBLIC;
GRANT EXECUTE ON METHOD EXT() FOR db2gse.ST_GEOMETRY TO PUBLIC;
GRANT EXECUTE ON METHOD EXT(DB2GSE.SE_EXTENSION) FOR db2gse.ST_GEOMETRY TO PUBLIC;
GRANT EXECUTE ON METHOD GEOMETRY_TYPE() FOR db2gse.ST_GEOMETRY TO PUBLIC;
GRANT EXECUTE ON METHOD GEOMETRY_TYPE(INTEGER) FOR db2gse.ST_GEOMETRY TO PUBLIC;
GRANT EXECUTE ON METHOD GEOMETRY_TYPE(SMALLINT) FOR db2gse.ST_GEOMETRY TO PUBLIC;
GRANT EXECUTE ON METHOD LENGTH() FOR db2gse.ST_GEOMETRY TO PUBLIC;
GRANT EXECUTE ON METHOD LENGTH(DOUBLE) FOR db2gse.ST_GEOMETRY TO PUBLIC;
GRANT EXECUTE ON METHOD MMAX() FOR db2gse.ST_GEOMETRY TO PUBLIC;
GRANT EXECUTE ON METHOD MMAX(DOUBLE) FOR db2gse.ST_GEOMETRY TO PUBLIC;
GRANT EXECUTE ON METHOD MMIN() FOR db2gse.ST_GEOMETRY TO PUBLIC;
GRANT EXECUTE ON METHOD MMIN(DOUBLE) FOR db2gse.ST_GEOMETRY TO PUBLIC;
GRANT EXECUTE ON METHOD NUMPOINTS() FOR db2gse.ST_GEOMETRY TO PUBLIC;
GRANT EXECUTE ON METHOD NUMPOINTS(INTEGER) FOR db2gse.ST_GEOMETRY TO PUBLIC;
GRANT EXECUTE ON METHOD POINTS() FOR db2gse.ST_GEOMETRY TO PUBLIC;
GRANT EXECUTE ON METHOD POINTS(BLOB) FOR db2gse.ST_GEOMETRY TO PUBLIC;
GRANT EXECUTE ON METHOD SRID() FOR db2gse.ST_GEOMETRY TO PUBLIC;
GRANT EXECUTE ON METHOD SRID(INTEGER) FOR db2gse.ST_GEOMETRY TO PUBLIC;
GRANT EXECUTE ON METHOD XMAX() FOR db2gse.ST_GEOMETRY TO PUBLIC;
GRANT EXECUTE ON METHOD XMAX(DOUBLE) FOR db2gse.ST_GEOMETRY TO PUBLIC;
GRANT EXECUTE ON METHOD XMIN() FOR db2gse.ST_GEOMETRY TO PUBLIC;
GRANT EXECUTE ON METHOD XMIN(DOUBLE) FOR db2gse.ST_GEOMETRY TO PUBLIC;
GRANT EXECUTE ON METHOD YMAX() FOR db2gse.ST_GEOMETRY TO PUBLIC;
GRANT EXECUTE ON METHOD YMAX(DOUBLE) FOR db2gse.ST_GEOMETRY TO PUBLIC;
GRANT EXECUTE ON METHOD YMIN() FOR db2gse.ST_GEOMETRY TO PUBLIC;
GRANT EXECUTE ON METHOD YMIN(DOUBLE) FOR db2gse.ST_GEOMETRY TO PUBLIC;
GRANT EXECUTE ON METHOD ZMAX() FOR db2gse.ST_GEOMETRY TO PUBLIC;
GRANT EXECUTE ON METHOD ZMAX(DOUBLE) FOR db2gse.ST_GEOMETRY TO PUBLIC;
GRANT EXECUTE ON METHOD ZMIN() FOR db2gse.ST_GEOMETRY TO PUBLIC;
GRANT EXECUTE ON METHOD ZMIN(DOUBLE) FOR db2gse.ST_GEOMETRY TO PUBLIC;

GRANT EXECUTE ON PACKAGE DB2GSE.GSE_DB   TO PUBLIC;
GRANT EXECUTE ON PACKAGE DB2GSE.GSE_DB   TO PUBLIC;
GRANT EXECUTE ON PACKAGE DB2GSE.GSE_SREF TO PUBLIC;
GRANT EXECUTE ON PACKAGE DB2GSE.GSE_SREF TO PUBLIC;
GRANT EXECUTE ON PACKAGE DB2GSE.GSE_LAYE TO PUBLIC;
GRANT EXECUTE ON PACKAGE DB2GSE.GSE_LAYE TO PUBLIC;
GRANT EXECUTE ON PACKAGE DB2GSE.GSE_IDX  TO PUBLIC;
GRANT EXECUTE ON PACKAGE DB2GSE.GSE_IDX  TO PUBLIC;
GRANT EXECUTE ON PACKAGE DB2GSE.GSE_GC   TO PUBLIC;
GRANT EXECUTE ON PACKAGE DB2GSE.GSE_GC   TO PUBLIC;
GRANT EXECUTE ON PACKAGE DB2GSE.GSE_IXPT TO PUBLIC;
GRANT EXECUTE ON PACKAGE DB2GSE.GSE_IXPT TO PUBLIC;
GRANT EXECUTE ON PACKAGE DB2GSE.GSEADM78 TO PUBLIC;
GRANT EXECUTE ON PACKAGE DB2GSE.GSEABMSB TO PUBLIC;
GRANT EXECUTE ON PACKAGE DB2GSE.GSEADMGC TO PUBLIC;
GRANT EXECUTE ON PACKAGE DB2GSE.GSEADMIX TO PUBLIC;
GRANT EXECUTE ON PACKAGE DB2GSE.GSEADCMN TO PUBLIC;
GRANT EXECUTE ON PACKAGE DB2GSE.GSEADDIS TO PUBLIC;
GRANT EXECUTE ON PACKAGE DB2GSE.GSEADDGC TO PUBLIC;
GRANT EXECUTE ON PACKAGE DB2GSE.GSEADENB TO PUBLIC;
GRANT EXECUTE ON PACKAGE DB2GSE.GSEADEGC TO PUBLIC;
GRANT EXECUTE ON PACKAGE DB2GSE.GSEADIXP TO PUBLIC;
GRANT EXECUTE ON PACKAGE DB2GSE.GSEADCDS TO PUBLIC;
GRANT EXECUTE ON PACKAGE DB2GSE.GSEADSRS TO PUBLIC;
GRANT EXECUTE ON PACKAGE DB2GSE.GSEADRGC TO PUBLIC;
GRANT EXECUTE ON PACKAGE DB2GSE.GSEADRLY TO PUBLIC;
GRANT EXECUTE ON PACKAGE DB2GSE.GSEADYGC TO PUBLIC;
GRANT EXECUTE ON PACKAGE DB2GSE.GSEADXGC TO PUBLIC;
GRANT EXECUTE ON PACKAGE DB2GSE.GSEADSGC TO PUBLIC;
GRANT EXECUTE ON PACKAGE DB2GSE.GSEADUGC TO PUBLIC;
GRANT EXECUTE ON PACKAGE DB2GSE.GSEADULY TO PUBLIC;
GRANT EXECUTE ON PACKAGE DB2GSE.GSECLADV TO PUBLIC;
GRANT EXECUTE ON PACKAGE DB2GSE.GSECLSTT TO PUBLIC;
GRANT EXECUTE ON PACKAGE DB2GSE.GSECLSQL TO PUBLIC;
GRANT EXECUTE ON PACKAGE DB2GSE.GSEIEEXP TO PUBLIC;
GRANT EXECUTE ON PACKAGE DB2GSE.GSEIEIMP TO PUBLIC;
GRANT EXECUTE ON PACKAGE DB2GSE.GSESCFCT TO PUBLIC;
GRANT EXECUTE ON PACKAGE DB2GSE.GSEADOIX TO PUBLIC;
GRANT EXECUTE ON PACKAGE DB2GSE.GSEADIXS TO PUBLIC;
GRANT EXECUTE ON PACKAGE DB2GSE.GSEADSRS TO PUBLIC;
GRANT EXECUTE ON PACKAGE DB2GSE.GSEADCMN TO PUBLIC;
GRANT EXECUTE ON PACKAGE DB2GSE.GSEADRLY TO PUBLIC;
GRANT EXECUTE ON PACKAGE DB2GSE.GSESCFCT TO PUBLIC;

COMMIT WORK;

CONNECT RESET;

TERMINATE;
